@@ -55,8 +55,7 @@ function cleanup_zaqar_mongodb {
     if ! timeout $SERVICE_TIMEOUT sh -c "while ! mongosh zaqar --eval 'db.dropDatabase();'; do sleep 1; done"; then
         die $LINENO "Mongo DB did not start"
     else
-        full_version=$(mongosh zaqar --eval 'db.dropDatabase();')
-        mongo_version=`echo $full_version | cut -d' ' -f11`
+        mongo_version=$(mongosh zaqar --eval 'db.version();')
         required_mongo_version='6.0'
         if [[ $mongo_version < $required_mongo_version ]]; then
             die $LINENO "Zaqar needs Mongo DB version >= 6.0 to run."
@@ -108,10 +107,6 @@ function configure_zaqar {
     iniset $ZAQAR_CONF DEFAULT pooling True
     iniset $ZAQAR_CONF 'pooling:catalog' enable_virtual_pool True
 
-    # NOTE(flaper87): Configure mongodb regardless so we can use it as a pool
-    # in tests.
-    configure_mongodb
-
     if [ "$ZAQAR_BACKEND" = 'mongodb' ] ; then
         iniset $ZAQAR_CONF  drivers message_store mongodb
         iniset $ZAQAR_CONF 'drivers:message_store:mongodb' uri mongodb://localhost:27017/zaqar
@@ -120,6 +115,7 @@ function configure_zaqar {
         iniset $ZAQAR_CONF  drivers management_store mongodb
         iniset $ZAQAR_CONF 'drivers:management_store:mongodb' uri mongodb://localhost:27017/zaqar_mgmt
         iniset $ZAQAR_CONF 'drivers:management_store:mongodb' database zaqar_mgmt
+        configure_mongodb
     elif [ "$ZAQAR_BACKEND" = 'redis' ] ; then
         recreate_database zaqar
         iniset $ZAQAR_CONF  drivers management_store sqlalchemy
@@ -192,10 +188,7 @@ function configure_mongodb {
         if [[ $ubuntu_version == '22.04' ]]; then
             wget -qO - https://www.mongodb.org/static/pgp/server-7.0.asc | sudo apt-key add -
             echo "deb [ arch=amd64,arm64 ] https://repo.mongodb.org/apt/ubuntu jammy/mongodb-org/7.0 multiverse" | sudo tee /etc/apt/sources.list.d/mongodb-org-7.0.list
-            echo "deb http://security.ubuntu.com/ubuntu bionic-security main" | sudo tee /etc/apt/sources.list.d/bionic-security.list
-            sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys 3B4FE6ACC0B21F32
             sudo apt update
-            install_package libssl1.1
             install_package mongodb-org
             restart_service mongod
             sudo systemctl status mongod
