@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from oslo_log import log as logging
 from osprofiler import profiler
 import redis
 import redis.sentinel
@@ -34,6 +35,8 @@ STRATEGY_TCP = 1
 STRATEGY_UNIX = 2
 STRATEGY_SENTINEL = 3
 
+LOG = logging.getLogger(__name__)
+
 
 class ConnectionURI(object):
     def __init__(self, uri):
@@ -46,21 +49,23 @@ class ConnectionURI(object):
         if parsed_url.scheme != 'redis':
             raise errors.ConfigurationError(_('Invalid scheme in Redis URI'))
 
-        # NOTE(kgriffs): Python 2.6 has a bug that causes the
-        # query string to be appended to the path when given a
-        # hostless URL.
         path = parsed_url.path
-        if '?' in path:
-            path, sep, query = path.partition('?')
-        else:
-            query = parsed_url.query
-        # NOTE(gengchc2): Redis connection support password configure.
-        self.password = None
-        if '@' in path:
-            self.password, sep, path = path.partition('@')
+        query = parsed_url.query
+        # NOTE(tkajinam): Replace '' by None
+        self.password = parsed_url.password or None
+        self.username = parsed_url.username or None
+
         netloc = parsed_url.netloc
         if '@' in netloc:
-            self.password, sep, netloc = netloc.partition('@')
+            cred, sep, netloc = netloc.partition('@')
+
+        if self.username and not self.password:
+            # NOTE(tkajinam): This is kept for backword compatibility but
+            #                 should be removed after 2025.1
+            LOG.warning('Credential in redis uri does not contain \':\'. '
+                        'Make sure that \':\' is added before password.')
+            self.password = self.username
+            self.username = None
 
         query_params = dict(urllib.parse.parse_qsl(query))
 
@@ -80,6 +85,8 @@ class ConnectionURI(object):
         # Sentinel
         self.master = None
         self.sentinels = []
+        self.sentinel_username = query_params.get('sentinel_username')
+        self.sentinel_password = query_params.get('sentinel_password')
 
         if 'master' in query_params:
             # NOTE(prashanthr_): Configure redis driver in sentinel mode
@@ -89,7 +96,14 @@ class ConnectionURI(object):
             # NOTE(kgriffs): Have to parse list of sentinel hosts ourselves
             # since urllib doesn't support it.
             for each_host in netloc.split(','):
-                name, sep, port = each_host.partition(':')
+                if not each_host.endswith(']') and ':' in each_host:
+                    name, sep, port = each_host.rpartition(':')
+                else:
+                    name = each_host
+                    port = None
+
+                if name.startswith('[') and name.endswith(']'):
+                    name = name[1:-1]
 
                 if port:
                     try:
@@ -98,7 +112,6 @@ class ConnectionURI(object):
                         msg = _('The Redis configuration URI contains an '
                                 'invalid port')
                         raise errors.ConfigurationError(msg)
-
                 else:
                     port = SENTINEL_DEFAULT_PORT
 
@@ -309,12 +322,14 @@ def _get_redis_client(driver):
         sentinel = redis.sentinel.Sentinel(
             connection_uri.sentinels,
             db=connection_uri.dbid,
+            username=connection_uri.username,
             password=connection_uri.password,
+            sentinel_kwargs={
+                'socket_timeout': connection_uri.socket_timeout,
+                'username': connection_uri.sentinel_username,
+                'password': connection_uri.sentinel_password
+            },
             socket_timeout=connection_uri.socket_timeout)
-
-        # NOTE(prashanthr_): The socket_timeout parameter being generic
-        # to all redis connections is inherited from the parameters for
-        # sentinel.
         return sentinel.master_for(connection_uri.master)
 
     elif connection_uri.strategy == STRATEGY_TCP:
@@ -322,11 +337,13 @@ def _get_redis_client(driver):
             host=connection_uri.hostname,
             port=connection_uri.port,
             db=connection_uri.dbid,
+            username=connection_uri.username,
             password=connection_uri.password,
             socket_timeout=connection_uri.socket_timeout)
     else:
         return redis.Redis(
             unix_socket_path=connection_uri.unix_socket_path,
             db=connection_uri.dbid,
+            username=connection_uri.username,
             password=connection_uri.password,
             socket_timeout=connection_uri.socket_timeout)
